@@ -1,27 +1,17 @@
 import sys
-from datetime import date
+from io import BufferedIOBase
 from json.decoder import JSONDecodeError
-from typing import Any, BinaryIO, List, Optional, Sequence, Tuple, Union
+from typing import Any, List, Optional, Tuple
 
 import aiohttp
-import pandas as pd
 import requests
 from aiohttp import ClientResponse
-from databento.common.bento import Bento, FileBento, MemoryBento
-from databento.common.enums import Dataset, Schema, SType
-from databento.common.logging import log_info
-from databento.common.parsing import (
-    datetime_to_string,
-    enum_or_str_lowercase,
-    maybe_symbols_list_to_string,
-)
 from databento.historical.error import BentoClientError, BentoServerError
 from databento.version import __version__
 from requests import Response
 from requests.auth import HTTPBasicAuth
 
 
-_NO_DATA_FOUND = b"No data found for query."
 _32KB = 1024 * 32  # 32_768
 
 
@@ -38,40 +28,6 @@ class BentoHttpAPI:
         self._gateway = gateway
         self._headers = {"accept": "application/json", "user-agent": user_agent}
 
-    @staticmethod
-    def _timeseries_params(
-        *,
-        dataset: Union[Dataset, str],
-        start: Union[pd.Timestamp, date, str, int],
-        end: Union[pd.Timestamp, date, str, int],
-        symbols: Optional[Union[List[str], str]] = None,
-        schema: Schema,
-        limit: Optional[int] = None,
-        stype_in: SType,
-        stype_out: SType = SType.PRODUCT_ID,
-    ) -> List[Tuple[str, Optional[str]]]:
-        params: List[Tuple[str, Any]] = [
-            ("dataset", enum_or_str_lowercase(dataset, "dataset")),
-            ("start", datetime_to_string(start)),
-            ("end", datetime_to_string(end)),
-            ("symbols", maybe_symbols_list_to_string(symbols) or "*"),
-            ("schema", schema.value),
-            ("stype_in", stype_in.value),
-            ("stype_out", stype_out.value),
-        ]
-
-        if limit is not None:
-            params.append(("limit", str(limit)))
-
-        return params
-
-    @staticmethod
-    def _create_bento(path: str) -> Union[MemoryBento, FileBento]:
-        if path is None:
-            return MemoryBento()
-        else:
-            return FileBento(path=path)
-
     def _check_api_key(self) -> None:
         if self._key == "YOUR_API_KEY":
             raise ValueError(
@@ -92,20 +48,18 @@ class BentoHttpAPI:
             url=url,
             params=params,
             headers=self._headers,
-            auth=HTTPBasicAuth(username=self._key, password=None)
-            if basic_auth
-            else None,
+            auth=HTTPBasicAuth(username=self._key, password="") if basic_auth else None,
             timeout=(self.TIMEOUT, self.TIMEOUT),
         ) as response:
             check_http_error(response)
             return response
 
-    async def _get_async(
+    async def _get_json_async(
         self,
         url: str,
         params: Optional[List[Tuple[str, Optional[str]]]] = None,
         basic_auth: bool = False,
-    ) -> ClientResponse:
+    ) -> Any:
         self._check_api_key()
         async with aiohttp.ClientSession() as session:
             async with session.get(
@@ -118,7 +72,7 @@ class BentoHttpAPI:
                 timeout=self.TIMEOUT,
             ) as response:
                 await check_http_error_async(response)
-                return response
+                return await response.json()
 
     def _post(
         self,
@@ -132,9 +86,7 @@ class BentoHttpAPI:
             url=url,
             params=params,
             headers=self._headers,
-            auth=HTTPBasicAuth(username=self._key, password=None)
-            if basic_auth
-            else None,
+            auth=HTTPBasicAuth(username=self._key, password="") if basic_auth else None,
             timeout=(self.TIMEOUT, self.TIMEOUT),
         ) as response:
             check_http_error(response)
@@ -145,7 +97,7 @@ class BentoHttpAPI:
         url: str,
         params: List[Tuple[str, Optional[str]]],
         basic_auth: bool,
-        bento: Bento,
+        writer: BufferedIOBase,
     ) -> None:
         self._check_api_key()
 
@@ -153,35 +105,21 @@ class BentoHttpAPI:
             url=url,
             params=params,
             headers=self._headers,
-            auth=HTTPBasicAuth(username=self._key, password=None)
-            if basic_auth
-            else None,
+            auth=HTTPBasicAuth(username=self._key, password="") if basic_auth else None,
             timeout=(self.TIMEOUT, self.TIMEOUT),
             stream=True,
         ) as response:
             check_http_error(response)
 
-            # Setup bento I/O writer
-            writer: BinaryIO = bento.writer()
-
             for chunk in response.iter_content(chunk_size=_32KB):
-                if chunk == _NO_DATA_FOUND:
-                    log_info("No data found for query.")
-                    return
                 writer.write(chunk)
 
-            if isinstance(bento, FileBento):
-                writer.close()
-
-            metadata = bento.source_metadata()
-            bento.set_metadata(metadata)
-
     async def _stream_async(
         self,
         url: str,
-        params: Sequence[Tuple[str, Optional[str]]],
+        params: List[Tuple[str, Optional[str]]],
         basic_auth: bool,
-        bento: Bento,
+        writer: BufferedIOBase,
     ) -> None:
         self._check_api_key()
 
@@ -197,21 +135,8 @@ class BentoHttpAPI:
             ) as response:
                 await check_http_error_async(response)
 
-                # Setup bento I/O writer
-                writer: BinaryIO = bento.writer()
-
                 async for chunk in response.content.iter_chunks():
-                    data: bytes = chunk[0]
-                    if data == _NO_DATA_FOUND:
-                        log_info("No data found for query.")
-                        return
-                    writer.write(data)
-
-                if isinstance(bento, FileBento):
-                    writer.close()
-
-                metadata = bento.source_metadata()
-                bento.set_metadata(metadata)
+                    writer.write(chunk[0])
 
 
 def is_400_series_error(status: int) -> bool:
@@ -256,18 +181,20 @@ def check_http_error(response: Response) -> None:
 async def check_http_error_async(response: ClientResponse) -> None:
     if is_500_series_error(response.status):
         json_body = await response.json()
+        http_body = await response.read()
         raise BentoServerError(
             http_status=response.status,
-            http_body=response.content,
+            http_body=http_body,
             json_body=json_body,
             message=json_body["detail"],
             headers=response.headers,
         )
     elif is_400_series_error(response.status):
         json_body = await response.json()
+        http_body = await response.read()
         raise BentoClientError(
             http_status=response.status,
-            http_body=response.content,
+            http_body=http_body,
             json_body=json_body,
             message=json_body["detail"],
             headers=response.headers,
